@@ -261,7 +261,9 @@ class ExperimentUnit(abc.ABC):
 
   def add(self,
           job: job_blocks.JobType,
-          args: Optional[Mapping[str, Any]] = None) -> Awaitable[None]:
+          args: Optional[Mapping[str, Any]] = None,
+          *,
+          identity: str = '') -> Awaitable[None]:
     # pyformat: disable
     """Adds a Job / JobGroup to the experiment unit.
 
@@ -281,6 +283,8 @@ class ExperimentUnit(abc.ABC):
         ```
 
         would update `args` field of a job `agent` in the group.
+      identity: Optional unique job identifier. If not empty, `add` adopts an
+        'add if not exists' behavior. No changes to existing job would be done.
 
     Returns:
       An awaitable that would be fulfilled when the job is launched.
@@ -294,11 +298,12 @@ class ExperimentUnit(abc.ABC):
     def launch_job(job: job_blocks.Job) -> Awaitable[None]:
       return self._launch_job_group(
           job_blocks.JobGroup(**{job.name: job}),
-          _work_unit_arguments(job, self._args))
+          _work_unit_arguments(job, self._args), identity)
 
     def launch_job_group(group: job_blocks.JobGroup) -> Awaitable[None]:
       return self._launch_job_group(group,
-                                    _work_unit_arguments(group, self._args))
+                                    _work_unit_arguments(group, self._args),
+                                    identity)
 
     def launch_job_generator(
         job_generator: job_blocks.JobGeneratorType) -> Awaitable[None]:
@@ -307,7 +312,9 @@ class ExperimentUnit(abc.ABC):
         raise ValueError(
             'Job generator must be an async function. Signature needs to be '
             '`async def job_generator(work_unit: xm.WorkUnit):`')
-      return job_generator(self, **(args or {}))
+      coroutine = job_generator(self, **(args or {}))
+      assert coroutine is not None
+      return coroutine
 
     job_awaitable = pattern_matching.match(launch_job, launch_job_group,
                                            launch_job_generator)(
@@ -325,7 +332,7 @@ class ExperimentUnit(abc.ABC):
     await self._wait_until_complete()
     return self
 
-  def wait_until_complete(self) -> Awaitable['ExperimentUnit']:
+  def wait_until_complete(self) -> Coroutine[Any, Any, 'ExperimentUnit']:
     """Waits until the unit is in a final state: completed/failed/stopped.
 
     Raises:
@@ -335,8 +342,12 @@ class ExperimentUnit(abc.ABC):
     """
     return self._wait_until_complete_impl()
 
-  async def _launch_job_group(self, job_group: job_blocks.JobGroup,
-                              args_view: Mapping[str, Any]) -> None:
+  async def _launch_job_group(
+      self,
+      job_group: job_blocks.JobGroup,
+      args_view: Mapping[str, Any],
+      identity: str,
+  ) -> None:
     """Launches a given job group as part of the unit."""
     raise NotImplementedError
 
@@ -404,7 +415,7 @@ class WorkUnitRole(ExperimentUnitRole):
   """
 
 
-class WorkUnitCompletedAwaitable:
+class WorkUnitCompletedAwaitable(Coroutine):
   """Awaitable for work unit completion event.
 
   Usage:
@@ -421,17 +432,29 @@ class WorkUnitCompletedAwaitable:
           print(f'Wor unit {wid} failed: {e}.')
   """
 
-  def __init__(self, work_unit: 'WorkUnit',
-               awaitable: Coroutine[Any, Any, ExperimentUnit]):
+  def __init__(self, work_unit: 'WorkUnit', awaitable: Callable[[],
+                                                                Any]) -> None:
     self.work_unit = work_unit
     self._awaitable = awaitable
+    self._wait_coro = self._wait()
 
   async def _wait(self) -> 'WorkUnit':
-    await self._awaitable
+    # Coroutine must be created inside of async function to avoid
+    # "coroutine ... was never awaited" runtime warning.
+    await self._awaitable()
     return self.work_unit
 
   def __await__(self) -> Generator[Any, None, 'WorkUnit']:
-    return self._wait().__await__()
+    return self._wait_coro.__await__()
+
+  def send(self, value: Any) -> Any:
+    return self._wait_coro.send(value)
+
+  def throw(self, type, value=None, traceback=None) -> Any:  # pylint: disable=redefined-builtin
+    return self._wait_coro.throw(type, value, traceback)
+
+  def close(self) -> None:
+    self._wait_coro.close()
 
 
 class WorkUnit(ExperimentUnit):
@@ -450,7 +473,7 @@ class WorkUnit(ExperimentUnit):
     Returns:
       Returns self to facilitate asyncio.as_completed usage.
     """
-    return WorkUnitCompletedAwaitable(self, self._wait_until_complete_impl())
+    return WorkUnitCompletedAwaitable(self, self._wait_until_complete_impl)
 
 
 @attr.s(auto_attribs=True, kw_only=True)
@@ -495,7 +518,9 @@ class AuxiliaryUnitJob(abc.ABC):
 
     async def launch_generator(
         job_generator: job_blocks.JobGeneratorType) -> None:
-      await job_generator(aux_unit, **kwargs)
+      coroutine = job_generator(aux_unit, **kwargs)
+      assert coroutine is not None
+      await coroutine
 
     async def launch_job(job: Any) -> None:
       aux_unit.add(job, args=kwargs)
@@ -548,7 +573,11 @@ class Experiment(abc.ABC):
 
   def _wait_for_tasks(self):
     while not self._running_tasks.empty():
-      self._running_tasks.get_nowait().result()
+      try:
+        self._running_tasks.get_nowait().result()
+      except futures.CancelledError:
+        # Ignore cancelled tasks.
+        pass
 
   def __exit__(self, exc_type, exc_value, traceback):
     self._wait_for_tasks()
@@ -623,9 +652,13 @@ class Experiment(abc.ABC):
     return cls._async_packager.add(packageable)
 
   @overload
-  def add(self,
-          job: AuxiliaryUnitJob,
-          args: Optional[Mapping[str, Any]] = ...) -> Awaitable[ExperimentUnit]:
+  def add(
+      self,
+      job: AuxiliaryUnitJob,
+      args: Optional[Mapping[str, Any]] = ...,
+      *,  # parameters after “*” are keyword-only parameters
+      identity: str = ''
+  ) -> asyncio.Future[ExperimentUnit]:
     ...
 
   @overload
@@ -634,8 +667,8 @@ class Experiment(abc.ABC):
       job: job_blocks.JobType,
       args: Optional[Mapping[str, Any]] = ...,
       *,  # parameters after “*” are keyword-only parameters
-      role: WorkUnitRole = ...
-  ) -> Awaitable[WorkUnit]:
+      role: WorkUnitRole = ...,
+      identity: str = '') -> asyncio.Future[WorkUnit]:
     ...
 
   @overload
@@ -644,8 +677,8 @@ class Experiment(abc.ABC):
       job: job_blocks.JobType,
       args: Optional[Mapping[str, Any]],
       *,  # parameters after “*” are keyword-only parameters
-      role: ExperimentUnitRole
-  ) -> Awaitable[ExperimentUnit]:
+      role: ExperimentUnitRole,
+      identity: str = '') -> asyncio.Future[ExperimentUnit]:
     ...
 
   @overload
@@ -654,12 +687,12 @@ class Experiment(abc.ABC):
       job: job_blocks.JobType,
       args: Optional[Mapping[str, Any]] = ...,
       *,  # parameters after “*” are keyword-only parameters
-      role: ExperimentUnitRole
-  ) -> Awaitable[ExperimentUnit]:
+      role: ExperimentUnitRole,
+      identity: str = '') -> asyncio.Future[ExperimentUnit]:
     ...
 
-  # The ExecutableUnit return type is determined by the role.
-  def add(self, job, args=None, *, role=WorkUnitRole()):
+  # The ExperimentUnit return type is determined by the role.
+  def add(self, job, args=None, *, role=WorkUnitRole(), identity: str = ''):
     # pyformat: disable
     """Adds a Job / JobGroup to the experiment.
 
@@ -679,6 +712,11 @@ class Experiment(abc.ABC):
 
         would update `args` field of a job `agent` in the group.
       role: The role of this unit in the experiment structure.
+      identity: Optional unique experiment unit identifier within the
+        experiment. If not empty, `add` adopts an 'add if not exists' behavior.
+        If a unit with the given identity already exists it will be returned as
+        is, without modifications. JobGenerators would still run to allow them
+        to recover after preemption.
 
     Returns:
       An awaitable that would be fulfilled when the job is launched.
@@ -689,19 +727,19 @@ class Experiment(abc.ABC):
         pattern_matching.Case([Any], lambda job: role),
     )(
         job)
-    experiment_unit_future = self._create_experiment_unit(args, role)
+    experiment_unit_future = self._create_experiment_unit(args, role, identity)
 
     async def launch():
       experiment_unit = await experiment_unit_future
-      await experiment_unit.add(job, args)
+      await experiment_unit.add(job, args, identity=identity)
       return experiment_unit
 
     return asyncio.wrap_future(self._create_task(launch()))
 
   @abc.abstractmethod
-  def _create_experiment_unit(
-      self, args: Optional[Mapping[str, Any]],
-      role: ExperimentUnitRole) -> Awaitable[ExperimentUnit]:
+  def _create_experiment_unit(self, args: Optional[Mapping[str, Any]],
+                              role: ExperimentUnitRole,
+                              identity: str) -> Awaitable[ExperimentUnit]:
     """Creates a new experiment unit.
 
     Synchronously starts the experiment unit creation, ensuring that IDs would
@@ -712,6 +750,7 @@ class Experiment(abc.ABC):
       args: Executable unit arguments, to be show as a part of hyper-parameter
         sweep.
       role: Executable unit role: whether to create a work or auxiliary unit.
+      identity: Optional user-given experiment unit id.
 
     Returns:
       An awaitable to the creation result.
